
Surfaces
========

Bigger comes with a number of pre-made surfaces.
These available within :mod:`bigger.load`

Flute
-----

.. image:: ../figures/flute.svg
    :height: 120
    :alt: Flute
    :target: ../_images/flute.svg
    :align: center

.. autofunction:: bigger.load.flute

Biflute
-------

.. image:: ../figures/biflute.svg
    :height: 120
    :alt: biflute
    :target: ../_images/biflute.svg
    :align: center

.. autofunction:: bigger.load.biflute

Cantor
------

.. image:: ../figures/cantor.svg
    :height: 400
    :alt: Cantor
    :target: ../_images/cantor.svg
    :align: center

.. autofunction:: bigger.load.cantor

Spotted Cantor
--------------

.. image:: ../figures/spotted_cantor.svg
    :height: 400
    :alt: Spotted Cantor
    :target: ../_images/spotted_cantor.svg
    :align: center

.. autofunction:: bigger.load.spotted_cantor

Ladder
------

.. image:: ../figures/ladder.svg
    :height: 120
    :alt: Ladder
    :target: ../_images/ladder.svg
    :align: center

.. autofunction:: bigger.load.ladder

